aboutsummaryrefslogtreecommitdiff
path: root/test_client.py
diff options
context:
space:
mode:
authorDaniel Teichmann <daniel.teichmann@das-netzwerkteam.de>2023-02-21 12:12:53 +0100
committerDaniel Teichmann <daniel.teichmann@das-netzwerkteam.de>2023-02-21 12:47:52 +0100
commit7d4ef7c8d59406705696d03cc3b3c192bdef5afa (patch)
tree781753fe43356c88187c812103ad8557370e87b9 /test_client.py
parenta38ec64a718917bd0998f7be6ce38e37a4af6b10 (diff)
downloadRWA.Support.SessionService-mr/stuff.tar.gz
RWA.Support.SessionService-mr/stuff.tar.bz2
RWA.Support.SessionService-mr/stuff.zip
test_client.py, (...)/service.py: Add host_alias field to 'add_web_app_host'.mr/stuff
Diffstat (limited to 'test_client.py')
-rwxr-xr-xtest_client.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/test_client.py b/test_client.py
index b646c4f..a7cb648 100755
--- a/test_client.py
+++ b/test_client.py
@@ -51,11 +51,12 @@ def get_web_app_hosts():
@cli.command()
-@click.argument("host", type=str)
-def add_web_app_host(host: str):
- """Add a RWA.Support.WebApp host. Requires <url>"""
- click.echo(f"Sending D-Bus request 'add_web_app_host': {host}")
- response = req.add_web_app_host(host)
+@click.argument("host_url", type=str)
+@click.argument("host_alias", type=str)
+def add_web_app_host(host_url: str, host_alias: str):
+ """Add a RWA.Support.WebApp host. Requires <url> <alias>"""
+ click.echo(f"Sending D-Bus request 'add_web_app_host': '{host_url}', '{host_alias}'")
+ response = req.add_web_app_host(host_url, host_alias)
click.echo(f"Your response is: {response}")